==> zio-aws-mediatailor_3-5.17.103.1-sources.jar: zio/aws/mediatailor/model/package.scala <==
package zio.aws.mediatailor
import zio.prelude.Subtype
import zio.aws.mediatailor.model.primitives.__string
import java.time.Instant
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object MaxResults extends Subtype[Int]
    type MaxResults = zio.aws.mediatailor.model.primitives.MaxResults.Type
    object __boolean extends Subtype[Boolean]
    type __boolean = zio.aws.mediatailor.model.primitives.__boolean.Type
    object __integer extends Subtype[Int]
    type __integer = zio.aws.mediatailor.model.primitives.__integer.Type
    object __integerMin1 extends Subtype[Int]
    type __integerMin1 = zio.aws.mediatailor.model.primitives.__integerMin1.Type
    object __integerMin1Max100 extends Subtype[Int]
    type __integerMin1Max100 =
      zio.aws.mediatailor.model.primitives.__integerMin1Max100.Type
    object __long extends Subtype[Long]
    type __long = zio.aws.mediatailor.model.primitives.__long.Type
    object __string extends Subtype[String]
    type __string = zio.aws.mediatailor.model.primitives.__string.Type
    object __timestampUnix extends Subtype[Instant]
    type __timestampUnix =
      zio.aws.mediatailor.model.primitives.__timestampUnix.Type
  }
  type ConfigurationAliasesRequest = Map[__string, Map[__string, __string]]
  type ConfigurationAliasesResponse = Map[__string, Map[__string, __string]]
  type HttpPackageConfigurations =
    List[zio.aws.mediatailor.model.HttpPackageConfiguration]
  type RequestOutputs = List[zio.aws.mediatailor.model.RequestOutputItem]
  type ResponseOutputs = List[zio.aws.mediatailor.model.ResponseOutputItem]
  type __listOfAdBreak = List[zio.aws.mediatailor.model.AdBreak]
  type __listOfAlert = List[zio.aws.mediatailor.model.Alert]
  type __listOfAvailMatchingCriteria =
    List[zio.aws.mediatailor.model.AvailMatchingCriteria]
  type __listOfChannel = List[zio.aws.mediatailor.model.Channel]
  type __listOfPlaybackConfiguration =
    List[zio.aws.mediatailor.model.PlaybackConfiguration]
  type __listOfPrefetchSchedule =
    List[zio.aws.mediatailor.model.PrefetchSchedule]
  type __listOfScheduleAdBreak = List[zio.aws.mediatailor.model.ScheduleAdBreak]
  type __listOfScheduleEntry = List[zio.aws.mediatailor.model.ScheduleEntry]
  type __listOfSourceLocation = List[zio.aws.mediatailor.model.SourceLocation]
  type __listOfVodSource = List[zio.aws.mediatailor.model.VodSource]
  type __listOf__string = List[__string]
  type __mapOf__string = Map[__string, __string]
}

==> zio-aws-mediatailor_3-5.17.124.3-sources.jar: zio/aws/mediatailor/model/package.scala <==
package zio.aws.mediatailor
import zio.prelude.Subtype
import zio.aws.mediatailor.model.primitives.__string
import java.time.Instant
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object MaxResults extends Subtype[Int]
    type MaxResults = zio.aws.mediatailor.model.primitives.MaxResults.Type
    object __boolean extends Subtype[Boolean]
    type __boolean = zio.aws.mediatailor.model.primitives.__boolean.Type
    object __integer extends Subtype[Int]
    type __integer = zio.aws.mediatailor.model.primitives.__integer.Type
    object __integerMin1 extends Subtype[Int]
    type __integerMin1 = zio.aws.mediatailor.model.primitives.__integerMin1.Type
    object __integerMin1Max100 extends Subtype[Int]
    type __integerMin1Max100 =
      zio.aws.mediatailor.model.primitives.__integerMin1Max100.Type
    object __long extends Subtype[Long]
    type __long = zio.aws.mediatailor.model.primitives.__long.Type
    object __string extends Subtype[String]
    type __string = zio.aws.mediatailor.model.primitives.__string.Type
    object __timestampUnix extends Subtype[Instant]
    type __timestampUnix =
      zio.aws.mediatailor.model.primitives.__timestampUnix.Type
  }
  type ConfigurationAliasesRequest = Map[__string, Map[__string, __string]]
  type ConfigurationAliasesResponse = Map[__string, Map[__string, __string]]
  type HttpPackageConfigurations =
    List[zio.aws.mediatailor.model.HttpPackageConfiguration]
  type RequestOutputs = List[zio.aws.mediatailor.model.RequestOutputItem]
  type ResponseOutputs = List[zio.aws.mediatailor.model.ResponseOutputItem]
  type __listOfAdBreak = List[zio.aws.mediatailor.model.AdBreak]
  type __listOfAlert = List[zio.aws.mediatailor.model.Alert]
  type __listOfAvailMatchingCriteria =
    List[zio.aws.mediatailor.model.AvailMatchingCriteria]
  type __listOfChannel = List[zio.aws.mediatailor.model.Channel]
  type __listOfPlaybackConfiguration =
    List[zio.aws.mediatailor.model.PlaybackConfiguration]
  type __listOfPrefetchSchedule =
    List[zio.aws.mediatailor.model.PrefetchSchedule]
  type __listOfScheduleAdBreak = List[zio.aws.mediatailor.model.ScheduleAdBreak]
  type __listOfScheduleEntry = List[zio.aws.mediatailor.model.ScheduleEntry]
  type __listOfSegmentDeliveryConfiguration =
    List[zio.aws.mediatailor.model.SegmentDeliveryConfiguration]
  type __listOfSourceLocation = List[zio.aws.mediatailor.model.SourceLocation]
  type __listOfVodSource = List[zio.aws.mediatailor.model.VodSource]
  type __listOf__string = List[__string]
  type __mapOf__string = Map[__string, __string]
}
